/*
 * SearchWorkcaseFilterBuilder.java
 * Copyright (c) 2011, W4.
 * All rights reserved.
 */

package GestionInterventions.builder;

import java.util.*;
import leon.control.*;
import leon.control.builder.*;
import leon.control.form.LyFieldController;
import leon.info.*;
import leon.misc.LyEnvironment;
import leon.misc.LyString;
import leon.view.*;
import leon.view.LyConstraintBase.HAlign;

/**
 * Creates a view to type in a filter with multiple criteria.
 *
 * @see LyFilterController
 */
public class SearchWorkcaseFilterBuilder extends LyMultiFilterBuilder
{
	/**
	 * Default constructor.
	 *
	 * @param parent parent controller
	 * @see leon.control.builder.LyMultiFilterBuilder#LyMultiFilterBuilder
	 */
	public SearchWorkcaseFilterBuilder(LyController parent)
	{
		super(parent);
	}

	

	@Override
	public LyFormField buildFormField(LyFieldInfo fieldInfo, boolean editable)
	{
		
	 LyFormField formField = super.buildFormField(fieldInfo, editable);
	 //the field will be align on the left
	 LyConstraint captionConstraint = new LyConstraint();
	 captionConstraint.setHAlign(HAlign.LEFT);
	 
	 LyCaption caption = formField.getCaption();
	 caption.setConstraint(captionConstraint);
	 
	 //deleting the constraints which could be set on the class
	 formField.setConstraint(null);
	 return formField;
	}
	

	@Override
	protected LyArea buildArea(String tabName)
	{
		LyFormController formController = (LyFormController) _parent;
		LyClassInfo classInfo = formController.getClassInfo();
		LyEnvironment environment = _parent.getEnvironment();

		if (classInfo == null) {
			environment
					.logWarning("LyFormBuilder : no classInfo was specified to build the form. Please check action parameters : "
							+ formController.getAction());
		}

		// building the form without group
		LyForm form = buildForm(tabName, null);

		LyArea area = new LyArea();
		area.setScrolling(LyArea.Scrolling.AUTO);
		area.addPanel(form);

		return area;
	}
	 
	@Override
	protected LyForm buildForm(String tabName, String group, int startIndex, boolean assemble)
	{
		LyClassInfo classInfo = ((LyFormController) _parent).getClassInfo();
		LyForm form = null;
		LyFormField formField;
		int i, n = ((classInfo == null) ? 0 : classInfo.getFieldInfoCount());
		LyFieldInfo fieldInfo;
		LyFormController formController = (LyFormController) _parent;
		String formId;
		LyFieldController fieldController;

		for (i = startIndex; i < n; i++) {
			fieldInfo = classInfo.getFieldInfo(i);
			if (!formController.isDisplayed(fieldInfo))
				continue; // Skipped

			fieldController = formController.getFieldController(fieldInfo);
			if (fieldController == null)
				continue;

			formField = fieldController.getFormField(fieldInfo);
			if (formField != null) {
				if (form == null) {
					formId = _parent.getId();
					// Replace space by underscore
					formId = LyString.replace(formId, " ", "_");
					form = new LyForm(formId);
					form.setController(_parent.getId());
					form.setBorder(false);
				}

				form.addFormField(formField);
			}
		}

	 return form;
	}

}
